#
# spec file for package python-mistralclient
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global oldpython python
Name:           python-mistralclient
Version:        5.3.0
Release:        1.2
Epoch:          0
Summary:        Python API and CLI for OpenStack Mistral
License:        Apache-2.0
Group:          Development/Languages/Python
URL:            https://docs.openstack.org/python-mistralclient
Source0:        https://files.pythonhosted.org/packages/source/p/python-mistralclient/python-mistralclient-5.3.0.tar.gz
BuildRequires:  openstack-macros
BuildRequires:  python3-PyYAML >= 3.13
BuildRequires:  python3-fixtures
BuildRequires:  python3-openstackclient
BuildRequires:  python3-osc-lib >= 1.8.0
BuildRequires:  python3-oslotest
BuildRequires:  python3-osprofiler
BuildRequires:  python3-pbr >= 2.0.0
BuildRequires:  python3-requests-mock
BuildRequires:  python3-stestr
BuildArch:      noarch

%description
Client library for Mistral built on the Mistral API. It provides a Python API
(the mistralclient module) and a command-line tool (mistral).

%package -n python3-mistralclient
Summary:        Python API and CLI for OpenStack Mistral
Requires:       python3-PyYAML >= 3.13
Requires:       python3-cliff >= 2.8.0
Requires:       python3-keystoneclient
Requires:       python3-osc-lib >= 1.8.0
Requires:       python3-oslo.i18n >= 3.15.3
Requires:       python3-oslo.utils >= 3.33.0
Requires:       python3-osprofiler
Requires:       python3-requests >= 2.14.2
Requires:       python3-stevedore >= 1.20.0
Conflicts:      %{oldpython}-mistralclient < %version

%description -n python3-mistralclient
Client library for Mistral built on the Mistral API. It provides a Python API
(the mistralclient module) and a command-line tool (mistral).

This package contains the Python 3.x module.

%package -n python-mistralclient-doc
Summary:        Documentation for OpenStack Mistral API client libary
Group:          Documentation/HTML
BuildRequires:  python3-Sphinx
BuildRequires:  python3-openstackdocstheme
BuildRequires:  python3-sphinxcontrib-apidoc

%description -n python-mistralclient-doc
Client library for Mistral built on the Mistral API. It provides a Python API
(the mistralclient module) and a command-line tool (mistral).
This package contains the documentation.

%prep
%autosetup -p1 -n python-mistralclient-5.3.0
%py_req_cleanup

%build
%{py3_build}

# Build HTML docs
PBR_VERSION=%{version} %sphinx_build -b html doc/source doc/build/html
rm -r doc/build/html/.{doctrees,buildinfo}

%install
%{py3_install}

%check
%{openstack_stestr_run}

%files -n python3-mistralclient
%license LICENSE
%{python3_sitelib}/mistralclient
%{python3_sitelib}/*.egg-info
%{_bindir}/mistral

%files -n python-mistralclient-doc
%license LICENSE
%doc README.rst doc/build/html

%changelog
* Tue Sep  3 2024 cloud-devel@suse.de
- update to version 5.3.0
  - Update master for stable/2024.1
* Sun Mar 24 2024 cloud-devel@suse.de
- update to version 5.2.0
  - Fix tox4 error and use python >=3.8
  - Update master for stable/zed
* Sun Jan 14 2024 cloud-devel@suse.de
- update to version 5.1.0
  - Update master for stable/yoga
  - Update master for stable/zed
  - Fix tox4 error and use python >=3.8
* Sat Jun 18 2022 Dirk Müller <dmueller@suse.com>
- add osc-lib dependency
* Tue May 24 2022 cloud-devel@suse.de
- update to version 4.4.0
  - version bump, no changes
- remove unnecessary dependencies
* Tue Oct 26 2021 cloud-devel@suse.de
- update to version 4.3.0
  - Drop lower-constraints job
  - [community goal] Update contributor documentation
  - Use py3 as the default runtime for tox
  - Update master for stable/wallaby
  - Allow enforcing usage of "raw" definitions
  - Add Python3 xena unit tests
  - Remove tripleo job from mistralclient
* Sun May  2 2021 cloud-devel@suse.de
- update to version 4.2.0
  - Remove install unnecessary packages
  - Update master for stable/victoria
  - Add Python3 wallaby unit tests
  - Add unit tests for dynamic actions CLI commands
  - Add unit tests for code sources CLI commands
  - Update TOX_CONSTRAINTS_FILE
  - remove unicode from code
  - Fix functional action CLI test
  - requirements: Drop os-testr
  - Add support for code sources and dynamic actions
* Fri Oct  9 2020 cloud-devel@suse.de
- update to version 4.1.1
  - Add py38 package metadata
  - Update master for stable/ussuri
  - Bump default tox env from py37 to py38
  - Use unittest.mock instead of third party mock
  - Add Python3 victoria unit tests
  - Fix hacking min version to 3.0.1
  - Remove all usage of six library
  - Switch to newer openstackdocstheme and reno versions
  - drop mock from lower-constraints
  - [goal] Migrate testing to ubuntu focal
  - added support statistics only for report execution API
* Tue May 12 2020 cloud-devel@suse.de
- update to version 4.0.1
  - [ussuri][goal] Drop python 2.7 support and testing
  - fixed compatibility issues between mistral and client
  - Switch to Ussuri jobs
  - tox: Keeping going with docs
  - Add namespace support for actions to client
  - Roots only option for executions-list
  - Add "duration" to task executions printed by CLI commands
  - Cleanup py27 support
  - Update hacking and fix warning
  - Update master for stable/train
  - Fix preinstalled workflows tests
  - fix the mistralclient set endpoint_type invaild
  - Add "duration" to workflow executions printed by CLI commands
  - Add script for unit test coverage job
  - Add new CLI commands for sub-executions new API endpoints
  - Create client for interactive shell
* Wed Mar 11 2020 Dirk Mueller <dmueller@suse.com>
- switch to python 3.x only builds
* Wed Oct  9 2019 cloud-devel@suse.de
- update to version 3.10.0
  - Use openstack-python3-train-jobs for python3 test runtime
  - Add "published_global" field to the task execution REST resource
  - Update sphinx dependency
  - Blacklist sphinx 2.1.0 (autodoc bug)
  - Dropping the py35 testing
  - Don't use default mutable parameter
  - Update master for stable/stein
  - Fix typo for self.list
  - Add Python 3 Train unit tests
  - Modify the url of upper_constraints_file
  - Replace openstack.org git:// URLs with https://
  - Add "retry_count" to execution report
  - Update json module to jsonutils
  - OpenDev Migration Patch
  - Some resource managers are not using the base underscore methods
  - Replace git.openstack.org URLs with opendev.org URLs
  - remove unused gate code
  - Change tripleo job to multinode-containers job
  - Bump openstackdocstheme to 1.30.0
  - Add python 3.7 classifier to setup.cfg
  - Rename the test class so it will be PyCharm friendly
* Tue Jun 11 2019 cloud-devel@suse.de
- update to version 3.8.1
  - Replace openstack.org git:// URLs with https://
  - OpenDev Migration Patch
  - Update .gitreview for stable/stein
  - Fix typo for self.list
  - Update UPPER_CONSTRAINTS_FILE for stable/stein
* Mon Apr  8 2019 cloud-devel@suse.de
- update to version 3.8.0
  - switch documentation job to new PTI
  - Remove tripleo newton and ocata jobs
  - Use template for lower-constraints
  - import zuul job settings from project-config
  - Fix execution report printing
  - Change openstack-dev to openstack-discuss
  - Update reno for stable/rocky
  - Update min tox version to 2.0
  - add python 3.6 unit test job
  - Replace tripleo-scenario003-multinode with scenario003-standalone
  - fix mistral client failure
  - Migrate python-mistralclient jobs to Zuul v3
  - Add Python 3.6 classifier to setup.cfg
  - Update links in README
  - Fix Chinese quotes
  - Follow the new PTI for document build
  - Provide consistent options and return latest execution entries
  - Add 'execution-get-report' command
  - Can't pause a async action using cli
  - Release note for the "execution-get-report" command
  - Remove setup.py check from pep8 job
  - Add namespace support for workbooks to client
  - Update hacking version
  - add python 3.7 unit test job
* Mon Sep  3 2018 cloud-devel@suse.de
- update to version 3.7.0
  - Fixing region filter for getting workflow endpoint
  - Update reno for stable/queens
  - Add namespace parameter to workflow-get and workflow-get-definition
  - Add the restructuredtext check to the flake8 job
  - Remove PyPI downloads
  - Add --export option to environment-get
  - Fix a race condition with execution creation
  - Add release note link in README
  - Revert "Adding environment-get-definition for easy environment-update"
  - Add the scope attribute in workflow list
  - Clean imports in code
  - Running new workflow based on existing execution.
  - Trivial: Update pypi url to new url
  - Remove broken tox-cover job
  - Fix force parameter being always added to URL in execution delete
  - Update task columns info
  - Adding environment-get-definition for easy environment-update
  - Add missing oslo.serialization requirement
  - Add TripleO jobs for mistral client
  - Restore devstack job for python-mistralclient
  - Add the force parameter to delete executions
  - Don't override session during auth
  - fix tox python3 overrides
  - Clarify details about the target cacert parameter
  - Add the root execution ID to the CLI output
  - Switch to using stestr
  - Add missing `--public` option to workbook api
  - Updated from global requirements
  - add lower-constraints job
  - Do not let keystoneauth mask the errors
* Fri Feb 23 2018 cloud-devel@suse.de
- update to version 3.3.0
  - Create and run a workflow within a namespace
  - Support for Project_domain_id and user_domain_id.
  - Update .gitreview for stable/queens
  - Avoid tox_install.sh for constraints support
  - Clean up keystone authentication
  - Use keystoneauth plugins and session instead of keystoneclient
  - Fix limit handling to not send value of -1
  - Namespaces release note
  - Fix how "--limit" is passed to the server for action executions
  - mistral execution-list -f value should be empty
  - Support no_auth mode in mistral client
  - Running new workflow based on existing execution.
  - Fix several problems in keycloak auth module
  - Remove "insecure" in token-based authentication.
  - Update and optimize documentation links
  - Update UPPER_CONSTRAINTS_FILE for stable/queens
  - Make README better
  - Task list now only queries the displayed fields.
  - Don't create client for help and bash completion
  - Add default values for domain related options
  - Don't override session during auth
  - Fix a typo in env variable name
  - Add test for target parameters and fix requests lib error
  - Update reno for stable/pike
  - Remove setting of version/release from releasenotes
  - Add CLI for event trigger operations
  - Enable ssl support for keycloak auth module
  - Updated from global requirements
- Switch to stable/queens spec template
* Mon Jan 15 2018 cloud-devel@suse.de
- update to version 3.1.4
  - Don't create client for help and bash completion
  - Fix several problems in keycloak auth module
  - Updated from global requirements
* Thu Sep 21 2017 cloud-devel@suse.de
- update to version 3.1.3
  - Fix how "--limit" is passed to the server for action executions
  - Update .gitreview for stable/pike
  - Enable ssl support for keycloak auth module
  - Updated from global requirements
  - Update UPPER_CONSTRAINTS_FILE for stable/pike
* Mon Aug  7 2017 cloud-devel@suse.de
- update to version 3.1.1
  - Remove white space between print () in cliutils.py and lintstack.py
  - Explicitly set 'builders' option
  - Add project_id and project_name options
  - Add release note for region name bugfix
  - Use oslotest instead of testtools/unittest
  - Initial commit for python-mistralclient document
  - Show team and repo badges on README
  - Fixing auth for keystone v2.0
  - Abstract authentication function
  - Add --utc flag to cron trigger create
  - Added sphinix config to setup.cfg
  - Add plug-in summary for osc doc
  - Take DST into account when converting to UTC
  - Trivial: Remove vim header from source files
  - Maintain releasenotes for python-mistralclient
  - Format the list of auth types in the Mistral client help
  - fix release note formatting
  - Enable DeprecationWarning in test environments
  - Fix for failing dsvm gate
  - Updated from global requirements
  - Expose the --run-sync Action Execution parameter on the CLI
  - Pass httpclient to managers
  - Enable some off-by-default checks
  - Send access info to server
  - String interpolation should be delayed
  - Update reno for stable/ocata
  - Accept keystone session in client
  - Region name related command line arguments are added
  - Fix wrong error message for environment operation
  - Give better tox output
  - Set the default value of --limit parameter
  - Removes unnecessary utf-8 encoding
  - Optimize the link address
  - Remove unused openstack/common/apiclient/client
  - Replace request mocking in test_httpclient with requests-mock
  - Update the gitingore
  - Remove commented-out Apache 2 classifier from setup.cfg
  - Updated tox.ini to pick up requirements from upper constraints
  - Update .gitignore
  - Fix python35 job failures
  - Change service type to workflowv2
  - Add '--filter' parameter to list commands in CLI
  - Fixed errors while generating releasenotes
  - Add filters to client Python APIs
  - Use assertGreater() or assertLess()
  - Make --profile load from environment variables
  - Make osprofiler dependency really "soft"
  - Add a missing space to the help message for execution-create
  - Move json.loads() method to utils.py, and use "with" to deal with file objects
  - Fix doc generation for python 3
  - Add cancelled state to action executions
  - Fix doc build if git is absent
  - Pass target insecure flag to msitral service
  - Keystone v3 needs extra parameters
  - Removing deprecation warnings to pass py35
  - Fixing getting mistral_url from keystone catalog
  - Added the reno for stable/mitaka stable/newton and stable/liberty
  - Added the # -*- coding: utf-8 -*- to the conf.py
  - Fix warning when running tox -e docs
  - Replaced savanna word with mistralclient
  - Make python mistralclient readme better
  - Adding files to .gitignore
  - Add Python 3.5 classifier and venv
  - Fix PEP8 issues and incorrect version/release details
  - Add tests for filters in CLI list commands
  - Read project_id and project_name in env
  - Replace uuid4() with generate_uuid() from oslo_utils
  - Removed the extra space from tox.ini
  - Use generic keystone client instead of versioned
  - Remove log translations
  - Update test requirement
  - Changed the README.rst
  - Remove support for py34
  - Remove unused pylint
  - remove openstack/common/cliutils.py
  - Refactor common parts of client tests
  - Avoid use xx=[] for parameter to initialize it's value
  - Enable release notes translation
  - Add user and project domain name parameters for target cloud
  - Filter workflow executions by creating task execution id
  - Remove unused scripts in tools
  - Fix region support in mistralclient
  - Use requests-mock for testing
  - Enable warning-is-error in doc build
  - Switch from oslosphinx to openstackdocstheme
  - Cosmetic changes in CLI tests
  - remove apiclient from mistralclient
  - Added link for modindex
  - Add 'created_at' and 'updated_at' to action-execution-get and action-execution-list command
  - doc: Remove cruft from conf.py
  - Add 'created_at' and 'updated_at' to task-get command
  - Use session from OSC plugin
  - Remove clashes of openstackclient command in mistral
  - Initial commit for mistral-i18n support
  - Removed openstack/common/importutils.py
  - Apply Pike document structure
* Fri Jun 23 2017 tbechtold@suse.com
- Switch to Ocata in _service
- update requirements
* Thu Jan  5 2017 dmueller@suse.com
- update to 2.1.2:
  * Remove clashes of openstackclient command in mistral
  * Make osprofiler dependency really "soft"
  * Added sphinix config to setup.cfg
  * Expose the --run-sync Action Execution parameter on the CLI
  * Update .gitreview for stable/newton
* Thu Oct 13 2016 dmueller@suse.com
- sync with git
* Fri Sep 30 2016 dmueller@suse.com
- update to 2.1.1:
  * Updated from global requirements
  * Updated from global requirements
  * Added ID option to update Action Definition
  * Add error message when OS_USERNAME or OS_PASSWORD not provided
  * Add target-* parameters to python-mistralclient
  * Different formatters for "action-execution-get" and "action-execution-list"
  * Add "Task ID" field for "action-execution-get" command output
  * Remove usage of private '_url' property from OSC
  * Add cancelled state to executions
  * Added 'pip install -r requirements.txt' instruction
  * Updated from global requirements
  * Fixed ssl options for httpclient
  * Changed argument names as per other python clients
  * Change action-get help to get action info by ID
  * Updated from global requirements
  * Add KeyCloak OpenID Connect authentication
  * Updated from global requirements
  * Use osc_lib instead of cliff
  * Use osc-lib instead of openstackclient
  * Updated from global requirements
  * Removed use of tempest_lib and used tempest instead
  * Updated from global requirements
  * Remove .mailmap since it's no longer needed
  * Updated from global requirements
  * Add osprofiler option to trace operations                                                  +* Remove AUTHORS file from git tracking
  * Updated from global requirements
  * Updated from global requirements
  * Updated from global requirements                                                           +* Updated from global requirements
  * Added CONTRIBUTING.rst file
  * Validate ad-hoc action via cli
  * Updated from global requirements
  * Updated from global requirements
  * Updated from global requirements
  * Fix task result syntax in workflows used for functional tests
  * Updated from global requirements
  * Fix cacert and insecure options on HTTP requests
  * Change the mistralclient for Mistral action pack
* Mon Sep  5 2016 tbechtold@suse.com
- Initial packaging (version 2.0.0)
